(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     28338,        761]
NotebookOptionsPosition[     27049,        712]
NotebookOutlinePosition[     27415,        728]
CellTagsIndexPosition[     27372,        725]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.56984228831815*^9, 3.5698423000337706`*^9}}],

Cell[CellGroupData[{

Cell["\<\
The Open Two - Level System with dephasing\
\>", "Title",
 CellChangeTimes->{{3.569596019512225*^9, 3.569596029444873*^9}, {
  3.569775146956011*^9, 3.569775159001007*^9}, {3.56984236213748*^9, 
  3.5698423643214836`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Rewriting the Master Equation in terms of the Coherence Vector\
\>", "Section",
 CellChangeTimes->{{3.569595851853923*^9, 3.569595873470957*^9}}],

Cell[CellGroupData[{

Cell["\<\
Define Pauli Matrices and 2\[Cross]2 Density Matrix\
\>", "Subsection",
 CellChangeTimes->{{3.5695957927494593`*^9, 3.569595829484969*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sx", "=", 
   RowBox[{"(", GridBox[{
      {"0", "1"},
      {"1", "0"}
     }], ")"}]}], ";", 
  RowBox[{"sy", "=", 
   RowBox[{"(", GridBox[{
      {"0", 
       RowBox[{"-", "I"}]},
      {"I", "0"}
     }], ")"}]}], ";", 
  RowBox[{"sz", "=", 
   RowBox[{"(", GridBox[{
      {"1", "0"},
      {"0", 
       RowBox[{"-", "1"}]}
     }], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sp", "=", 
   RowBox[{"(", GridBox[{
      {"0", "1"},
      {"0", "0"}
     }], ")"}]}], ";", 
  RowBox[{"sm", "=", 
   RowBox[{"(", GridBox[{
      {"0", "0"},
      {"1", "0"}
     }], ")"}]}], ";", " ", 
  RowBox[{"idy", "=", 
   RowBox[{"(", GridBox[{
      {"1", "0"},
      {"0", "1"}
     }], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]", "=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{"idy", "+", 
      RowBox[{"rx", " ", "sx"}], "+", 
      RowBox[{"ry", " ", "sy"}], "+", 
      RowBox[{"rz", " ", "sz"}]}], ")"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5695882377558317`*^9, 3.569588316774025*^9}, {
   3.569588481537898*^9, 3.569588481759996*^9}, {3.569596003130587*^9, 
   3.569596010001306*^9}, {3.569596072307137*^9, 3.569596115509221*^9}, 
   3.56959660131884*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define the right - hand side of the Master Equation", "Subsection",
 CellChangeTimes->{{3.5695958825602627`*^9, 3.5695958969910603`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RHS", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "I"}], " ", "\[Epsilon]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"sp", ".", "sm", ".", "\[Rho]"}], "-", 
       RowBox[{"\[Rho]", ".", "sp", ".", "sm"}]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["\[Gamma]", "2"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"sz", ".", "\[Rho]", ".", "sz"}], "-", "\[Rho]"}], ")"}]}]}]}],
   ";"}]], "Input",
 CellChangeTimes->{{3.569588321176948*^9, 3.5695884071853867`*^9}, 
   3.569595840496244*^9, 3.569606700957611*^9, {3.5698424057863564`*^9, 
   3.5698424214019837`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Tr", "[", 
     RowBox[{"s\[Alpha]", ".", "RHS"}], "]"}], "//", "Simplify"}], ",", 
   RowBox[{"{", 
    RowBox[{"s\[Alpha]", ",", 
     RowBox[{"{", 
      RowBox[{"sx", ",", "sy", ",", "sz"}], "}"}]}], "}"}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.5695884173123703`*^9, 3.569588428534457*^9}, {
  3.569588525064389*^9, 3.569588525872243*^9}, {3.569588614181226*^9, 
  3.569588614321681*^9}, {3.5695959184240017`*^9, 3.569595996024118*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "rx"}], " ", "\[Gamma]"}], "-", 
    RowBox[{"ry", " ", "\[Epsilon]"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "ry"}], " ", "\[Gamma]"}], "+", 
    RowBox[{"rx", " ", "\[Epsilon]"}]}], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.5695884243858747`*^9, 3.569588428752034*^9}, 
   3.569588485166588*^9, 3.569588526189583*^9, 3.569588614979327*^9, 
   3.5695938372156878`*^9, {3.56959594241891*^9, 3.569595996478506*^9}, 
   3.569606705383093*^9, 3.5697550009098873`*^9, 3.5698424239135885`*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Solving and Plotting Solutions on the Bloch Sphere\
\>", "Section",
 CellChangeTimes->{{3.569597395136273*^9, 3.569597417370867*^9}, {
  3.570271795739949*^9, 3.570271798501154*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Gmat", "[", 
    RowBox[{"\[Epsilon]_", ",", "\[Gamma]_"}], "]"}], ":=", 
   RowBox[{"(", GridBox[{
      {
       RowBox[{"-", "\[Gamma]"}], 
       RowBox[{"-", "\[Epsilon]"}], "0"},
      {"\[Epsilon]", 
       RowBox[{"-", "\[Gamma]"}], "0"},
      {"0", "0", "0"}
     }], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bvec", "[", "\[Gamma]_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.569606936685193*^9, 3.569606999412496*^9}, {
  3.5698424570324464`*^9, 3.5698424638028584`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SolveMasterEq", "[", 
     RowBox[{"rini_List", ",", "eps_", ",", "gam_", ",", "tmax_"}], "]"}], ":=", 
    RowBox[{"NDSolve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Thread", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"rx", "'"}], "[", "t", "]"}], ",", 
           RowBox[{
            RowBox[{"ry", "'"}], "[", "t", "]"}], ",", 
           RowBox[{
            RowBox[{"rz", "'"}], "[", "t", "]"}]}], "}"}], "\[Equal]", 
         RowBox[{
          RowBox[{
           RowBox[{"Gmat", "[", 
            RowBox[{"eps", ",", "gam"}], "]"}], ".", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"rx", "[", "t", "]"}], ",", 
             RowBox[{"ry", "[", "t", "]"}], ",", 
             RowBox[{"rz", "[", "t", "]"}]}], "}"}]}], "+", 
          RowBox[{"bvec", "[", "gam", "]"}]}]}], "]"}], "~", "Join", "~", 
       RowBox[{"Thread", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"rx", "[", "0", "]"}], ",", 
           RowBox[{"ry", "[", "0", "]"}], ",", 
           RowBox[{"rz", "[", "0", "]"}]}], "}"}], "\[Equal]", "rini"}], 
        "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"rx", ",", "ry", ",", "rz"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", 
        RowBox[{"-", "0.1"}], ",", "tmax"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"BlochSpherePlot", "[", 
     RowBox[{"sol_", ",", "t_"}], "]"}], ":=", "\[IndentingNewLine]", 
    RowBox[{"GraphicsGrid", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Show", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Graphics3D", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Opacity", "[", "0.6", "]"}], ",", 
                  RowBox[{"Sphere", "[", 
                   RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "0"}], "}"}], "]"}]}], "}"}], 
                ",", 
                RowBox[{"{", 
                 RowBox[{"Red", ",", 
                  RowBox[{"Arrowheads", "[", "0.05", "]"}], ",", 
                  RowBox[{"Arrow", "[", 
                   RowBox[{"Tube", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"rx", "[", "t", "]"}], ",", 
                    RowBox[{"ry", "[", "t", "]"}], ",", 
                    RowBox[{"rz", "[", "t", "]"}]}], "}"}], "/.", "sol"}]}], 
                    "}"}], ",", "0.025"}], "]"}], "]"}]}], "}"}]}], "}"}], 
              ",", 
              RowBox[{"ViewPoint", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"1", ",", "1.3", ",", "1.5"}], "}"}]}], ",", 
              RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
              RowBox[{"PlotLabel", "\[Rule]", "\"\<Tilted\>\""}]}], "]"}], 
            ",", 
            RowBox[{"ParametricPlot3D", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"rx", "[", "t1", "]"}], ",", 
                 RowBox[{"ry", "[", "t1", "]"}], ",", 
                 RowBox[{"rz", "[", "t1", "]"}]}], "}"}], "/.", "sol"}], ",", 
              
              RowBox[{"{", 
               RowBox[{"t1", ",", "0", ",", "t"}], "}"}], ",", 
              RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
              RowBox[{"PlotPoints", "\[Rule]", "80"}]}], "]"}]}], "}"}], 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Show", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Graphics3D", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Opacity", "[", "0.6", "]"}], ",", 
                  RowBox[{"Sphere", "[", 
                   RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "0"}], "}"}], "]"}]}], "}"}], 
                ",", 
                RowBox[{"{", 
                 RowBox[{"Red", ",", 
                  RowBox[{"Arrowheads", "[", "0.05", "]"}], ",", 
                  RowBox[{"Arrow", "[", 
                   RowBox[{"Tube", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"rx", "[", "t", "]"}], ",", 
                    RowBox[{"ry", "[", "t", "]"}], ",", 
                    RowBox[{"rz", "[", "t", "]"}]}], "}"}], "/.", "sol"}]}], 
                    "}"}], ",", "0.025"}], "]"}], "]"}]}], "}"}]}], "}"}], 
              ",", 
              RowBox[{"ViewPoint", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], ",", 
              RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
              RowBox[{"PlotLabel", "\[Rule]", "\"\<Side\>\""}]}], "]"}], ",", 
            
            RowBox[{"ParametricPlot3D", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"rx", "[", "t1", "]"}], ",", 
                 RowBox[{"ry", "[", "t1", "]"}], ",", 
                 RowBox[{"rz", "[", "t1", "]"}]}], "}"}], "/.", "sol"}], ",", 
              
              RowBox[{"{", 
               RowBox[{"t1", ",", "0", ",", "t"}], "}"}], ",", 
              RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
              RowBox[{"PlotPoints", "\[Rule]", "80"}]}], "]"}]}], "}"}], 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Show", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Graphics3D", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Opacity", "[", "0.6", "]"}], ",", 
                  RowBox[{"Sphere", "[", 
                   RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "0"}], "}"}], "]"}]}], "}"}], 
                ",", 
                RowBox[{"{", 
                 RowBox[{"Red", ",", 
                  RowBox[{"Arrowheads", "[", "0.05", "]"}], ",", 
                  RowBox[{"Arrow", "[", 
                   RowBox[{"Tube", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"rx", "[", "t", "]"}], ",", 
                    RowBox[{"ry", "[", "t", "]"}], ",", 
                    RowBox[{"rz", "[", "t", "]"}]}], "}"}], "/.", "sol"}]}], 
                    "}"}], ",", "0.025"}], "]"}], "]"}]}], "}"}]}], "}"}], 
              ",", 
              RowBox[{"ViewPoint", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], ",", 
              RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
              RowBox[{"PlotLabel", "\[Rule]", "\"\<Top\>\""}]}], "]"}], ",", 
            RowBox[{"ParametricPlot3D", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"rx", "[", "t1", "]"}], ",", 
                 RowBox[{"ry", "[", "t1", "]"}], ",", 
                 RowBox[{"rz", "[", "t1", "]"}]}], "}"}], "/.", "sol"}], ",", 
              
              RowBox[{"{", 
               RowBox[{"t1", ",", "0", ",", "t"}], "}"}], ",", 
              RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
              RowBox[{"PlotPoints", "\[Rule]", "80"}]}], "]"}]}], "}"}], 
          "]"}]}], "}"}], "}"}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", 
       RowBox[{"1", "/", "2"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "1200"}], ",", 
      RowBox[{"PlotLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<time=\>\"", ",", "t"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"\"\<purity=\>\"", ",", 
           RowBox[{"purity", "[", 
            RowBox[{"sol", ",", "t"}], "]"}]}], "}"}]}], "}"}]}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ExpectPlot", "[", 
    RowBox[{"sol_", ",", "t_"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"rx", "[", "t1", "]"}], "/.", "sol"}], ",", 
          RowBox[{"{", 
           RowBox[{"t1", ",", "0", ",", "t"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "80"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"Frame", "\[Rule]", "True"}], ",", 
          RowBox[{"FrameLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<time\>\"", ",", 
             "\"\<\[LeftAngleBracket]\!\(\*SubscriptBox[\(\[Sigma]\), \
\(x\)]\)\[RightAngleBracket]\>\""}], "}"}]}], ",", 
          RowBox[{"LabelStyle", "\[Rule]", 
           RowBox[{"Directive", "[", "Medium", "]"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
          RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}], ",", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ry", "[", "t1", "]"}], "/.", "sol"}], ",", 
          RowBox[{"{", 
           RowBox[{"t1", ",", "0", ",", "t"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "80"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"Frame", "\[Rule]", "True"}], ",", 
          RowBox[{"FrameLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<time\>\"", ",", 
             "\"\<\[LeftAngleBracket]\!\(\*SubscriptBox[\(\[Sigma]\), \
\(y\)]\)\[RightAngleBracket]\>\""}], "}"}]}], ",", 
          RowBox[{"LabelStyle", "\[Rule]", 
           RowBox[{"Directive", "[", "Medium", "]"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
          RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}], ",", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            FractionBox["1", "2"], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"rz", "[", "t1", "]"}]}], ")"}]}], "/.", "sol"}], ",", 
          RowBox[{"{", 
           RowBox[{"t1", ",", "0", ",", "t"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "80"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"Frame", "\[Rule]", "True"}], ",", 
          RowBox[{"FrameLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<time\>\"", ",", 
             "\"\<\!\(\*SubscriptBox[\(p\), \(exc\)]\)\>\""}], "}"}]}], ",", 
          RowBox[{"LabelStyle", "\[Rule]", 
           RowBox[{"Directive", "[", "Medium", "]"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
          RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}], ",", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"purity", "[", 
           RowBox[{"sol", ",", "t1"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"t1", ",", "0", ",", "t"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "80"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"Frame", "\[Rule]", "True"}], ",", 
          RowBox[{"FrameLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<time\>\"", ",", "\"\<purity\>\""}], "}"}]}], ",", 
          RowBox[{"LabelStyle", "\[Rule]", 
           RowBox[{"Directive", "[", "Medium", "]"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
          RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]}], "}"}], "}"}], 
     ",", 
     RowBox[{"PlotLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<time=\>\"", ",", "t"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"\"\<purity=\>\"", ",", 
          RowBox[{"purity", "[", 
           RowBox[{"sol", ",", "t"}], "]"}]}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.569607083895061*^9, 3.5696071732648*^9}, {
  3.569607503709608*^9, 3.569607507293356*^9}, {3.569608617913476*^9, 
  3.5696086205046463`*^9}, {3.5702728352129755`*^9, 3.57027287207584*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", "solution", "}"}], "=", 
   RowBox[{"SolveMasterEq", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", "1", ",", "0.1", ",", 
     "80.0"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.569607174956212*^9, 3.569607208432138*^9}, {
   3.569607933076653*^9, 3.569607977147922*^9}, {3.5696080406221313`*^9, 
   3.56960804071749*^9}, {3.569608850212266*^9, 3.569608851946005*^9}, {
   3.569608890277034*^9, 3.5696089056597643`*^9}, {3.5696095301435633`*^9, 
   3.569609533630446*^9}, 3.570272866803031*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", "solution", "}"}], "=", 
   RowBox[{"SolveMasterEq", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", "1", ",", "0.1", ",", 
     "80.0"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.569609525055953*^9, 3.5696095438795853`*^9}, {
  3.569758059596528*^9, 3.569758061051017*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", "solution", "}"}], "=", 
   RowBox[{"SolveMasterEq", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.8", ",", "0", ",", 
       SqrtBox[
        RowBox[{"1", "-", 
         SuperscriptBox["0.8", "2"]}]]}], "}"}], ",", "1", ",", "0.1", ",", 
     "80.0"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.569758404761632*^9, 3.569758428744542*^9}, {
  3.569764612590417*^9, 3.56976461541201*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Animate", "[", 
  RowBox[{
   RowBox[{"BlochSpherePlot", "[", 
    RowBox[{"solution", ",", "tm"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"tm", ",", "0.00001", ",", "80.0"}], "}"}], ",", 
   RowBox[{"AnimationRate", "\[Rule]", "2"}], ",", 
   RowBox[{"AnimationRunning", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5696066230813513`*^9, 3.5696066573433323`*^9}, {
  3.569606796008731*^9, 3.569606810367961*^9}, {3.569607261423945*^9, 
  3.569607267599353*^9}, {3.569607702056333*^9, 3.569607714159953*^9}, {
  3.569607945821087*^9, 3.569607980972126*^9}, {3.5696080538066673`*^9, 
  3.569608053901559*^9}, {3.5696087127462473`*^9, 3.569608713903985*^9}, {
  3.5696102136676683`*^9, 3.569610237177952*^9}, {3.569610275157693*^9, 
  3.5696102755470247`*^9}, {3.569610332637887*^9, 3.5696103328060226`*^9}, {
  3.569610392181602*^9, 3.569610395358747*^9}, {3.569756340165371*^9, 
  3.56975634049995*^9}, {3.569756377875457*^9, 3.569756377958804*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`tm$$ = 39., Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`tm$$], 0.00001, 80.}}, Typeset`size$$ = {
    237., {2., 8.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`tm$249545$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`tm$$ = 0.00001}, 
      "ControllerVariables" :> {
        Hold[$CellContext`tm$$, $CellContext`tm$249545$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`BlochSpherePlot[$CellContext`solution, \
$CellContext`tm$$], 
      "Specifications" :> {{$CellContext`tm$$, 0.00001, 80., AnimationRate -> 
         2, AnimationRunning -> False, 
         AppearanceElements -> {
          "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
           "DirectionButton"}}}, 
      "Options" :> {
       ControlType -> Animator, AppearanceElements -> None, DefaultBaseStyle -> 
        "Animate", DefaultLabelStyle -> "AnimateLabel", SynchronousUpdating -> 
        True, ShrinkingDelay -> 10.}, "DefaultOptions" :> {}],
     ImageSizeCache->{342., {44., 49.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Animate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.569609128825634*^9, 3.569609182242284*^9, {3.5696101880513773`*^9, 
   3.56961023826228*^9}, 3.569610276122064*^9, 3.56961033447351*^9, 
   3.56961039608969*^9, 3.56975634151429*^9, 3.569756378822412*^9, 
   3.5697580109410667`*^9, {3.569758049542788*^9, 3.569758075293816*^9}, {
   3.569758409085799*^9, 3.56975843789429*^9}, 3.569764620755452*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.569610527414176*^9, 3.569610622081647*^9}, {
   3.569610679540544*^9, 3.569610703629229*^9}, {3.5696118932501163`*^9, 
   3.569611913747607*^9}, {3.569755905742457*^9, 3.569755912446885*^9}, {
   3.569756075962686*^9, 3.569756242014269*^9}, {3.569756403936739*^9, 
   3.569756404602275*^9}, {3.569757910204997*^9, 3.5697579254357643`*^9}, {
   3.569757962671698*^9, 3.569757993780842*^9}, {3.569758026223399*^9, 
   3.569758032172995*^9}, {3.56975815768721*^9, 3.5697582054082747`*^9}, {
   3.569764922550796*^9, 3.569764922694251*^9}, 3.5702728529814067`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Animate", "[", 
  RowBox[{
   RowBox[{"ExpectPlot", "[", 
    RowBox[{"solution", ",", "tm"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"tm", ",", "0.00001", ",", "80.0"}], "}"}], ",", 
   RowBox[{"AnimationRate", "\[Rule]", "4"}], ",", 
   RowBox[{"AnimationRunning", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.569610632162198*^9, 3.569610638370448*^9}, {
  3.56975627386062*^9, 3.569756323348634*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`tm$$ = 80., Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`tm$$], 0.00001, 80.}}, Typeset`size$$ = {
    197., {2., 8.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`tm$26522$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`tm$$ = 0.00001}, 
      "ControllerVariables" :> {
        Hold[$CellContext`tm$$, $CellContext`tm$26522$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`ExpectPlot[$CellContext`solution, \
$CellContext`tm$$], 
      "Specifications" :> {{$CellContext`tm$$, 0.00001, 80., AnimationRate -> 
         4, AnimationRunning -> False, 
         AppearanceElements -> {
          "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
           "DirectionButton"}}}, 
      "Options" :> {
       ControlType -> Animator, AppearanceElements -> None, DefaultBaseStyle -> 
        "Animate", DefaultLabelStyle -> "AnimateLabel", SynchronousUpdating -> 
        True, ShrinkingDelay -> 10.}, "DefaultOptions" :> {}],
     ImageSizeCache->{342., {44., 49.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Animate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.569610638842841*^9, {3.569756276073185*^9, 3.569756323816258*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1352, 633},
WindowMargins->{{-1, Automatic}, {Automatic, 0}},
ShowSelection->True,
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (November 20, 2012)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 141, 2, 31, "Input"],
Cell[CellGroupData[{
Cell[723, 26, 232, 5, 90, "Title"],
Cell[CellGroupData[{
Cell[980, 35, 155, 3, 79, "Section"],
Cell[CellGroupData[{
Cell[1160, 42, 149, 3, 43, "Subsection"],
Cell[1312, 47, 1279, 47, 110, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2628, 99, 143, 1, 43, "Subsection"],
Cell[2774, 102, 623, 18, 44, "Input"],
Cell[CellGroupData[{
Cell[3422, 124, 519, 13, 31, "Input"],
Cell[3944, 139, 594, 14, 31, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4599, 160, 192, 4, 79, "Section"],
Cell[4794, 166, 639, 19, 82, "Input"],
Cell[5436, 187, 13739, 342, 539, "Input"],
Cell[19178, 531, 597, 13, 31, "Input"],
Cell[19778, 546, 375, 10, 31, "Input"],
Cell[20156, 558, 453, 13, 45, "Input"],
Cell[CellGroupData[{
Cell[20634, 575, 994, 17, 31, "Input"],
Cell[21631, 594, 2284, 45, 110, "Output"]
}, Open  ]],
Cell[23930, 642, 609, 8, 31, "Input"],
Cell[CellGroupData[{
Cell[24564, 654, 448, 10, 31, "Input"],
Cell[25015, 666, 1994, 41, 110, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
