(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     30742,        832]
NotebookOptionsPosition[     29394,        782]
NotebookOutlinePosition[     29860,        800]
CellTagsIndexPosition[     29817,        797]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell["The Open Two - Level System coupled to finite-T bath", "Title",
 CellChangeTimes->{{3.569596019512225*^9, 3.569596029444873*^9}, {
  3.569775137195801*^9, 3.569775175593501*^9}}],

Cell[CellGroupData[{

Cell["\<\
Rewriting the Master Equation in terms of the Coherence Vector\
\>", "Section",
 CellChangeTimes->{{3.569595851853923*^9, 3.569595873470957*^9}}],

Cell[CellGroupData[{

Cell["\<\
Define Pauli Matrices and 2\[Cross]2 Density Matrix\
\>", "Subsection",
 CellChangeTimes->{{3.5695957927494593`*^9, 3.569595829484969*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sx", "=", 
   RowBox[{"(", GridBox[{
      {"0", "1"},
      {"1", "0"}
     }], ")"}]}], ";", 
  RowBox[{"sy", "=", 
   RowBox[{"(", GridBox[{
      {"0", 
       RowBox[{"-", "I"}]},
      {"I", "0"}
     }], ")"}]}], ";", 
  RowBox[{"sz", "=", 
   RowBox[{"(", GridBox[{
      {"1", "0"},
      {"0", 
       RowBox[{"-", "1"}]}
     }], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sp", "=", 
   RowBox[{"(", GridBox[{
      {"0", "1"},
      {"0", "0"}
     }], ")"}]}], ";", 
  RowBox[{"sm", "=", 
   RowBox[{"(", GridBox[{
      {"0", "0"},
      {"1", "0"}
     }], ")"}]}], ";", " ", 
  RowBox[{"id", "=", 
   RowBox[{"(", GridBox[{
      {"1", "0"},
      {"0", "1"}
     }], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]", "=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{"id", "+", 
      RowBox[{"rx", " ", "sx"}], "+", 
      RowBox[{"ry", " ", "sy"}], "+", 
      RowBox[{"rz", " ", "sz"}]}], ")"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5695882377558317`*^9, 3.569588316774025*^9}, {
   3.569588481537898*^9, 3.569588481759996*^9}, {3.569596003130587*^9, 
   3.569596010001306*^9}, {3.569596072307137*^9, 3.569596115509221*^9}, 
   3.56959660131884*^9, {3.5702704763502297`*^9, 3.5702704781910334`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define the right - hand side of the Master Equation", "Subsection",
 CellChangeTimes->{{3.5695958825602627`*^9, 3.5695958969910603`*^9}}],

Cell[TextData[{
 "Below, \[Eta] abbreviates ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", 
    RowBox[{
     RowBox[{"-", "\[Beta]"}], " ", "\[Epsilon]"}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "."
}], "Text",
 CellChangeTimes->{{3.569775264739439*^9, 3.5697752871633463`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RHS", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "I"}], " ", "\[Epsilon]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"sp", ".", "sm", ".", "\[Rho]"}], "-", 
       RowBox[{"\[Rho]", ".", "sp", ".", "sm"}]}], ")"}]}], "+", 
    RowBox[{"\[Gamma]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"sm", ".", "\[Rho]", ".", "sp"}], "-", 
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"sp", ".", "sm", ".", "\[Rho]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"\[Rho]", ".", "sp", ".", "sm"}]}]}], ")"}]}], "+", 
    RowBox[{"\[Gamma]", " ", "\[Eta]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"sp", ".", "\[Rho]", ".", "sm"}], "-", 
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"sm", ".", "sp", ".", "\[Rho]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"\[Rho]", ".", "sm", ".", "sp"}]}]}], ")"}]}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.569588321176948*^9, 3.5695884071853867`*^9}, 
   3.569595840496244*^9, 3.569606700957611*^9, {3.569769625348628*^9, 
   3.569769639732152*^9}, {3.56977519189394*^9, 3.569775203172865*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Tr", "[", 
      RowBox[{"s\[Alpha]", ".", "RHS"}], "]"}], "//", "Simplify"}], ",", 
    RowBox[{"{", 
     RowBox[{"s\[Alpha]", ",", 
      RowBox[{"{", 
       RowBox[{"sx", ",", "sy", ",", "sz"}], "}"}]}], "}"}]}], "]"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.5695884173123703`*^9, 3.569588428534457*^9}, {
  3.569588525064389*^9, 3.569588525872243*^9}, {3.569588614181226*^9, 
  3.569588614321681*^9}, {3.5695959184240017`*^9, 3.569595996024118*^9}, {
  3.569770151100363*^9, 3.569770152204873*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "ry", " ", "\[Epsilon]"}], "-", 
      RowBox[{"rx", " ", "\[Gamma]", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "\[Eta]"}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"rx", " ", "\[Epsilon]"}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "ry", " ", "\[Gamma]", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "\[Eta]"}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", "\[Gamma]"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "rz", "-", "\[Eta]", "+", 
      RowBox[{"rz", " ", "\[Eta]"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.5695884243858747`*^9, 3.569588428752034*^9}, 
   3.569588485166588*^9, 3.569588526189583*^9, 3.569588614979327*^9, 
   3.5695938372156878`*^9, {3.56959594241891*^9, 3.569595996478506*^9}, 
   3.569606705383093*^9, 3.5697550009098873`*^9, 3.569769641456427*^9, 
   3.569770152527625*^9, 3.569775296587101*^9, 3.569842786286625*^9, 
   3.5702705706231956`*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solving and Plotting Solutions on the Bloch Sphere", "Section",
 CellChangeTimes->{{3.569597395136273*^9, 3.569597417370867*^9}, {
   3.570270506022482*^9, 3.570270508674487*^9}, 3.570275333146364*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Gmat", "[", 
    RowBox[{"\[Epsilon]_", ",", "\[Gamma]_", ",", "\[Eta]_"}], "]"}], ":=", 
   RowBox[{"(", GridBox[{
      {
       RowBox[{
        RowBox[{"-", "\[Gamma]"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "\[Eta]"}], ")"}], "/", "2"}]}], 
       RowBox[{"-", "\[Epsilon]"}], "0"},
      {"\[Epsilon]", 
       RowBox[{
        RowBox[{"-", "\[Gamma]"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "\[Eta]"}], ")"}], "/", "2"}]}], "0"},
      {"0", "0", 
       RowBox[{
        RowBox[{"-", "\[Gamma]"}], 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Eta]"}], ")"}]}]}
     }], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"bvec", "[", 
     RowBox[{"\[Gamma]_", ",", "\[Eta]_"}], "]"}], ":=", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", 
      RowBox[{
       RowBox[{"-", "\[Gamma]"}], 
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Eta]"}], ")"}]}]}], "}"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SolveMasterEq", "[", 
     RowBox[{
     "rini_List", ",", "eps_", ",", "gam_", ",", "eta_", ",", "tmax_"}], 
     "]"}], ":=", 
    RowBox[{"NDSolve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Thread", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"rx", "'"}], "[", "t", "]"}], ",", 
           RowBox[{
            RowBox[{"ry", "'"}], "[", "t", "]"}], ",", 
           RowBox[{
            RowBox[{"rz", "'"}], "[", "t", "]"}]}], "}"}], "\[Equal]", 
         RowBox[{
          RowBox[{
           RowBox[{"Gmat", "[", 
            RowBox[{"eps", ",", "gam", ",", "eta"}], "]"}], ".", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"rx", "[", "t", "]"}], ",", 
             RowBox[{"ry", "[", "t", "]"}], ",", 
             RowBox[{"rz", "[", "t", "]"}]}], "}"}]}], "+", 
          RowBox[{"bvec", "[", 
           RowBox[{"gam", ",", "eta"}], "]"}]}]}], "]"}], "~", "Join", "~", 
       RowBox[{"Thread", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"rx", "[", "0", "]"}], ",", 
           RowBox[{"ry", "[", "0", "]"}], ",", 
           RowBox[{"rz", "[", "0", "]"}]}], "}"}], "\[Equal]", "rini"}], 
        "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"rx", ",", "ry", ",", "rz"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", 
        RowBox[{"-", "0.1"}], ",", "tmax"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"purity", "[", 
     RowBox[{"sol_", ",", "t_"}], "]"}], ":=", 
    FractionBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox[
        RowBox[{"Norm", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"rx", "[", "t", "]"}], ",", 
            RowBox[{"ry", "[", "t", "]"}], ",", 
            RowBox[{"rz", "[", "t", "]"}]}], "}"}], "/.", "sol"}], "]"}], 
        "2"]}], ")"}], "2"]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"BlochSpherePlot", "[", 
     RowBox[{"sol_", ",", "t_"}], "]"}], ":=", "\[IndentingNewLine]", 
    RowBox[{"GraphicsGrid", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Show", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Graphics3D", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Opacity", "[", "0.6", "]"}], ",", 
                  RowBox[{"Sphere", "[", 
                   RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "0"}], "}"}], "]"}]}], "}"}], 
                ",", 
                RowBox[{"{", 
                 RowBox[{"Red", ",", 
                  RowBox[{"Arrowheads", "[", "0.05", "]"}], ",", 
                  RowBox[{"Arrow", "[", 
                   RowBox[{"Tube", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"rx", "[", "t", "]"}], ",", 
                    RowBox[{"ry", "[", "t", "]"}], ",", 
                    RowBox[{"rz", "[", "t", "]"}]}], "}"}], "/.", "sol"}]}], 
                    "}"}], ",", "0.025"}], "]"}], "]"}]}], "}"}]}], "}"}], 
              ",", 
              RowBox[{"ViewPoint", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"1", ",", "1.3", ",", "1.5"}], "}"}]}], ",", 
              RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
              RowBox[{"PlotLabel", "\[Rule]", "\"\<Tilted\>\""}]}], "]"}], 
            ",", 
            RowBox[{"ParametricPlot3D", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"rx", "[", "t1", "]"}], ",", 
                 RowBox[{"ry", "[", "t1", "]"}], ",", 
                 RowBox[{"rz", "[", "t1", "]"}]}], "}"}], "/.", "sol"}], ",", 
              
              RowBox[{"{", 
               RowBox[{"t1", ",", "0", ",", "t"}], "}"}], ",", 
              RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
              RowBox[{"PlotPoints", "\[Rule]", "40"}]}], "]"}]}], "}"}], 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Show", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Graphics3D", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Opacity", "[", "0.6", "]"}], ",", 
                  RowBox[{"Sphere", "[", 
                   RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "0"}], "}"}], "]"}]}], "}"}], 
                ",", 
                RowBox[{"{", 
                 RowBox[{"Red", ",", 
                  RowBox[{"Arrowheads", "[", "0.05", "]"}], ",", 
                  RowBox[{"Arrow", "[", 
                   RowBox[{"Tube", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"rx", "[", "t", "]"}], ",", 
                    RowBox[{"ry", "[", "t", "]"}], ",", 
                    RowBox[{"rz", "[", "t", "]"}]}], "}"}], "/.", "sol"}]}], 
                    "}"}], ",", "0.025"}], "]"}], "]"}]}], "}"}]}], "}"}], 
              ",", 
              RowBox[{"ViewPoint", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], ",", 
              RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
              RowBox[{"PlotLabel", "\[Rule]", "\"\<Side\>\""}]}], "]"}], ",", 
            
            RowBox[{"ParametricPlot3D", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"rx", "[", "t1", "]"}], ",", 
                 RowBox[{"ry", "[", "t1", "]"}], ",", 
                 RowBox[{"rz", "[", "t1", "]"}]}], "}"}], "/.", "sol"}], ",", 
              
              RowBox[{"{", 
               RowBox[{"t1", ",", "0", ",", "t"}], "}"}], ",", 
              RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
              RowBox[{"PlotPoints", "\[Rule]", "40"}]}], "]"}]}], "}"}], 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Show", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Graphics3D", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Opacity", "[", "0.6", "]"}], ",", 
                  RowBox[{"Sphere", "[", 
                   RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "0"}], "}"}], "]"}]}], "}"}], 
                ",", 
                RowBox[{"{", 
                 RowBox[{"Red", ",", 
                  RowBox[{"Arrowheads", "[", "0.05", "]"}], ",", 
                  RowBox[{"Arrow", "[", 
                   RowBox[{"Tube", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"rx", "[", "t", "]"}], ",", 
                    RowBox[{"ry", "[", "t", "]"}], ",", 
                    RowBox[{"rz", "[", "t", "]"}]}], "}"}], "/.", "sol"}]}], 
                    "}"}], ",", "0.025"}], "]"}], "]"}]}], "}"}]}], "}"}], 
              ",", 
              RowBox[{"ViewPoint", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], ",", 
              RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
              RowBox[{"PlotLabel", "\[Rule]", "\"\<Top\>\""}]}], "]"}], ",", 
            RowBox[{"ParametricPlot3D", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"rx", "[", "t1", "]"}], ",", 
                 RowBox[{"ry", "[", "t1", "]"}], ",", 
                 RowBox[{"rz", "[", "t1", "]"}]}], "}"}], "/.", "sol"}], ",", 
              
              RowBox[{"{", 
               RowBox[{"t1", ",", "0", ",", "t"}], "}"}], ",", 
              RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
              RowBox[{"PlotPoints", "\[Rule]", "40"}]}], "]"}]}], "}"}], 
          "]"}]}], "}"}], "}"}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", 
       RowBox[{"1", "/", "2"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "1200"}], ",", 
      RowBox[{"PlotLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<time=\>\"", ",", "t"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"\"\<purity=\>\"", ",", 
           RowBox[{"purity", "[", 
            RowBox[{"sol", ",", "t"}], "]"}]}], "}"}]}], "}"}]}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ExpectPlot", "[", 
    RowBox[{"sol_", ",", "t_"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"rx", "[", "t1", "]"}], "/.", "sol"}], ",", 
          RowBox[{"{", 
           RowBox[{"t1", ",", "0", ",", "t"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "80"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"Frame", "\[Rule]", "True"}], ",", 
          RowBox[{"FrameLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<time\>\"", ",", 
             "\"\<\[LeftAngleBracket]\!\(\*SubscriptBox[\(\[Sigma]\), \
\(x\)]\)\[RightAngleBracket]\>\""}], "}"}]}], ",", 
          RowBox[{"LabelStyle", "\[Rule]", 
           RowBox[{"Directive", "[", "Medium", "]"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
          RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}], ",", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ry", "[", "t1", "]"}], "/.", "sol"}], ",", 
          RowBox[{"{", 
           RowBox[{"t1", ",", "0", ",", "t"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "80"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"Frame", "\[Rule]", "True"}], ",", 
          RowBox[{"FrameLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<time\>\"", ",", 
             "\"\<\[LeftAngleBracket]\!\(\*SubscriptBox[\(\[Sigma]\), \
\(y\)]\)\[RightAngleBracket]\>\""}], "}"}]}], ",", 
          RowBox[{"LabelStyle", "\[Rule]", 
           RowBox[{"Directive", "[", "Medium", "]"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
          RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}], ",", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            FractionBox["1", "2"], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"rz", "[", "t1", "]"}]}], ")"}]}], "/.", "sol"}], ",", 
          RowBox[{"{", 
           RowBox[{"t1", ",", "0", ",", "t"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "80"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"Frame", "\[Rule]", "True"}], ",", 
          RowBox[{"FrameLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<time\>\"", ",", 
             "\"\<\!\(\*SubscriptBox[\(p\), \(exc\)]\)\>\""}], "}"}]}], ",", 
          RowBox[{"LabelStyle", "\[Rule]", 
           RowBox[{"Directive", "[", "Medium", "]"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
          RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}], ",", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"purity", "[", 
           RowBox[{"sol", ",", "t1"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"t1", ",", "0", ",", "t"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "80"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"Frame", "\[Rule]", "True"}], ",", 
          RowBox[{"FrameLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<time\>\"", ",", "\"\<purity\>\""}], "}"}]}], ",", 
          RowBox[{"LabelStyle", "\[Rule]", 
           RowBox[{"Directive", "[", "Medium", "]"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
          RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]}], "}"}], "}"}], 
     ",", 
     RowBox[{"PlotLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<time=\>\"", ",", "t"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"\"\<purity=\>\"", ",", 
          RowBox[{"purity", "[", 
           RowBox[{"sol", ",", "t"}], "]"}]}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.569606936685193*^9, 3.569606999412496*^9}, {
  3.569775748752117*^9, 3.569775762398275*^9}, {3.570272145324963*^9, 
  3.5702721477273674`*^9}, {3.5702727782572756`*^9, 3.5702728039973207`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", "solution", "}"}], "=", 
   RowBox[{"SolveMasterEq", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", "1", ",", "0.1", ",", 
     "0.5", ",", "80.0"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.569607174956212*^9, 3.569607208432138*^9}, {
  3.569607933076653*^9, 3.569607977147922*^9}, {3.5696080406221313`*^9, 
  3.56960804071749*^9}, {3.569608850212266*^9, 3.569608851946005*^9}, {
  3.569608890277034*^9, 3.5696089056597643`*^9}, {3.5696095301435633`*^9, 
  3.569609533630446*^9}, {3.569775844615724*^9, 3.569775844982463*^9}, {
  3.5702723127308574`*^9, 3.5702723154764624`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", "solution", "}"}], "=", 
   RowBox[{"SolveMasterEq", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", "1", ",", "0.1", ",", 
     "0.5", ",", "80.0"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.569609525055953*^9, 3.5696095438795853`*^9}, {
  3.569758059596528*^9, 3.569758061051017*^9}, {3.569775849336478*^9, 
  3.569775850407523*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", "solution", "}"}], "=", 
   RowBox[{"SolveMasterEq", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.8", ",", "0", ",", 
       SqrtBox[
        RowBox[{"1", "-", 
         SuperscriptBox["0.8", "2"]}]]}], "}"}], ",", "1", ",", "0", ",", 
     "0.0", ",", "80.0"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.569758404761632*^9, 3.569758428744542*^9}, {
   3.569764612590417*^9, 3.56976461541201*^9}, {3.569775853071528*^9, 
   3.569775853599663*^9}, 3.569775945825656*^9, {3.569776001603455*^9, 
   3.569776002561042*^9}, {3.5702723180504665`*^9, 3.570272318097267*^9}, {
   3.5702785275547314`*^9, 3.570278528022732*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Animate", "[", 
  RowBox[{
   RowBox[{"BlochSpherePlot", "[", 
    RowBox[{"solution", ",", "tm"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"tm", ",", "0.00001", ",", "80.0"}], "}"}], ",", 
   RowBox[{"AnimationRate", "\[Rule]", "2"}], ",", 
   RowBox[{"AnimationRunning", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5696066230813513`*^9, 3.5696066573433323`*^9}, {
  3.569606796008731*^9, 3.569606810367961*^9}, {3.569607261423945*^9, 
  3.569607267599353*^9}, {3.569607702056333*^9, 3.569607714159953*^9}, {
  3.569607945821087*^9, 3.569607980972126*^9}, {3.5696080538066673`*^9, 
  3.569608053901559*^9}, {3.5696087127462473`*^9, 3.569608713903985*^9}, {
  3.5696102136676683`*^9, 3.569610237177952*^9}, {3.569610275157693*^9, 
  3.5696102755470247`*^9}, {3.569610332637887*^9, 3.5696103328060226`*^9}, {
  3.569610392181602*^9, 3.569610395358747*^9}, {3.569756340165371*^9, 
  3.56975634049995*^9}, {3.569756377875457*^9, 3.569756377958804*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`tm$$ = 46.67215107513428, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`tm$$], 0.00001, 80.}}, Typeset`size$$ = {
    900., {168., 169.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`tm$307601$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`tm$$ = 0.00001}, 
      "ControllerVariables" :> {
        Hold[$CellContext`tm$$, $CellContext`tm$307601$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`BlochSpherePlot[$CellContext`solution, \
$CellContext`tm$$], 
      "Specifications" :> {{$CellContext`tm$$, 0.00001, 80., AnimationRate -> 
         2, AnimationRunning -> False, 
         AppearanceElements -> {
          "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
           "DirectionButton"}}}, 
      "Options" :> {
       ControlType -> Animator, AppearanceElements -> None, DefaultBaseStyle -> 
        "Animate", DefaultLabelStyle -> "AnimateLabel", SynchronousUpdating -> 
        True, ShrinkingDelay -> 10.}, "DefaultOptions" :> {}],
     ImageSizeCache->{941., {199., 202.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Animate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.569609128825634*^9, 3.569609182242284*^9, {3.5696101880513773`*^9, 
   3.56961023826228*^9}, 3.569610276122064*^9, 3.56961033447351*^9, 
   3.56961039608969*^9, 3.56975634151429*^9, 3.569756378822412*^9, 
   3.5697580109410667`*^9, {3.569758049542788*^9, 3.569758075293816*^9}, {
   3.569758409085799*^9, 3.56975843789429*^9}, 3.569764620755452*^9, {
   3.5697757951871767`*^9, 3.569775806031989*^9}, 3.569775875893742*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Animate", "[", 
  RowBox[{
   RowBox[{"ExpectPlot", "[", 
    RowBox[{"solution", ",", "tm"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"tm", ",", "0.00001", ",", "80.0"}], "}"}], ",", 
   RowBox[{"AnimationRate", "\[Rule]", "4"}], ",", 
   RowBox[{"AnimationRunning", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.569610632162198*^9, 3.569610638370448*^9}, {
  3.56975627386062*^9, 3.569756323348634*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`tm$$ = 80., Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`tm$$], 0.00001, 80.}}, Typeset`size$$ = {
    981., {77., 78.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`tm$313279$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`tm$$ = 0.00001}, 
      "ControllerVariables" :> {
        Hold[$CellContext`tm$$, $CellContext`tm$313279$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`ExpectPlot[$CellContext`solution, \
$CellContext`tm$$], 
      "Specifications" :> {{$CellContext`tm$$, 0.00001, 80., AnimationRate -> 
         4, AnimationRunning -> False, 
         AppearanceElements -> {
          "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
           "DirectionButton"}}}, 
      "Options" :> {
       ControlType -> Animator, AppearanceElements -> None, DefaultBaseStyle -> 
        "Animate", DefaultLabelStyle -> "AnimateLabel", SynchronousUpdating -> 
        True, ShrinkingDelay -> 10.}, "DefaultOptions" :> {}],
     ImageSizeCache->{1022., {108., 111.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Animate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.569610638842841*^9, {3.569756276073185*^9, 3.569756323816258*^9}, 
   3.569775910444953*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1024, 690},
WindowMargins->{{Automatic, 0}, {0, Automatic}},
ShowSelection->True,
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 0.75, 0.75 Inherited],
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (November 20, 2012)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 74, 1, 24, "Input"],
Cell[CellGroupData[{
Cell[656, 25, 184, 2, 68, "Title"],
Cell[CellGroupData[{
Cell[865, 31, 155, 3, 59, "Section"],
Cell[CellGroupData[{
Cell[1045, 38, 149, 3, 32, "Subsection"],
Cell[1197, 43, 1327, 47, 88, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2561, 95, 143, 1, 32, "Subsection"],
Cell[2707, 98, 300, 10, 24, "Text"],
Cell[3010, 110, 1189, 33, 34, "Input"],
Cell[CellGroupData[{
Cell[4224, 147, 608, 15, 23, "Input"],
Cell[4835, 164, 1094, 28, 34, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5990, 199, 207, 2, 59, "Section"],
Cell[6200, 203, 15426, 399, 560, "Input"],
Cell[21629, 604, 682, 14, 24, "Input"],
Cell[22314, 620, 436, 11, 24, "Input"],
Cell[22753, 633, 686, 16, 32, "Input"],
Cell[CellGroupData[{
Cell[23464, 653, 994, 17, 24, "Input"],
Cell[24461, 672, 2378, 46, 414, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26876, 723, 448, 10, 24, "Input"],
Cell[27327, 735, 2027, 42, 232, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
